@@ -1,5 +1,7 @@
 #!/bin/bash -ex
 
+ControlPath=/tmp/openssh-mux-client-test.socket
+
 stop_ssh_tester() {
     exit_code=$?
     testfiles/stop.sh
@@ -28,8 +30,18 @@ if [ $# -lt 1 ]; then
     cargo test test_unordered -- --nocapture
     cargo test test_request_stop_listening -- --nocapture
 
+    if [ -e $ControlPath ]; then
+        echo request_stop_listening does not work
+        exit 1
+    fi
+
     start_ssh_tester
     cargo test test_sync_request_stop_listening -- --nocapture
+
+    if [ -e $ControlPath ]; then
+        echo shutdown_mux_master does not work
+        exit 1
+    fi
 else
     cargo test $@ -- --nocapture
 fi
