@@ -7,6 +7,7 @@ use crate::request::{Fwd, Request};
 use core::num::{NonZeroU32, Wrapping};
 
 use std::borrow::Cow;
+use std::ffi::CStr;
 use std::os::unix::io::RawFd;
 use std::path::Path;
 
@@ -265,8 +266,8 @@ impl Connection {
     pub async fn sftp(self, fds: &[RawFd; 3]) -> Result<EstablishedSession> {
         let session = Session::builder()
             .subsystem(true)
-            .term(Cow::Borrowed(""))
-            .cmd(Cow::Borrowed("sftp"))
+            .term(Cow::Borrowed(CStr::from_bytes_with_nul(b"\0").unwrap()))
+            .cmd(Cow::Borrowed(CStr::from_bytes_with_nul(b"sftp\0").unwrap()))
             .build();
 
         self.open_new_session(&session, fds).await
@@ -416,6 +417,7 @@ mod tests {
 
     use core::time::Duration;
     use std::env;
+    use std::ffi::CString;
     use std::io;
     use std::os::unix::io::AsRawFd;
 
@@ -477,7 +479,9 @@ mod tests {
         conn: Connection,
         cmd: &str,
     ) -> (EstablishedSession, (PipeWrite, PipeRead)) {
-        let session = Session::builder().cmd(cmd.into()).build();
+        let session = Session::builder()
+            .cmd(Cow::Owned(CString::new(cmd).unwrap()))
+            .build();
 
         // pipe() returns (PipeRead, PipeWrite)
         let (stdin_read, stdin_write) = pipe().unwrap();
@@ -667,4 +671,6 @@ mod tests {
         test_request_stop_listening,
         test_request_stop_listening_impl
     );
+
+    // TODO: Test request::Session::env
 }
